@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -19,4 +19,9 @@
 
 """A framework for the creation of autonomous agent services."""
 
+from pathlib import Path
+
 from .__version__ import __version__
+
+
+AUTONOMY_DIR = Path(__file__).resolve().parent
