@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2022-2023 Valory AG
+#   Copyright 2022-2024 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -19,6 +19,8 @@
 
 """Deployment helpers."""
 import os
+import shutil
+import time
 from pathlib import Path
 from typing import Dict, List, Optional, Tuple
 
@@ -27,17 +29,19 @@ from aea.configurations.data_types import PublicId
 from aea.helpers.base import cd
 from compose.cli import main as docker_compose
 from compose.config.errors import ConfigurationError
+from compose.project import Project, ProjectError
 from docker.errors import NotFound
 
 from autonomy.chain.config import ChainType, ContractConfigs
 from autonomy.chain.exceptions import FailedToRetrieveComponentMetadata
 from autonomy.chain.service import get_agent_instances, get_service_info
 from autonomy.chain.utils import resolve_component_id
-from autonomy.cli.helpers.chain import get_ledger_and_crypto_objects
+from autonomy.cli.helpers.chain import OnChainHelper
 from autonomy.cli.helpers.registry import fetch_service_ipfs
 from autonomy.configurations.constants import DEFAULT_SERVICE_CONFIG_FILE
 from autonomy.configurations.loader import load_service_config
 from autonomy.constants import DEFAULT_BUILD_FOLDER
+from autonomy.deploy.base import Resources
 from autonomy.deploy.build import generate_deployment
 from autonomy.deploy.constants import (
     AGENT_KEYS_DIR,
@@ -72,16 +76,33 @@ def _build_dirs(build_dir: Path) -> None:
             click.echo(
                 f"Updating permissions failed for {path}, please do it manually."
             )
+        except AttributeError:  # pragma: no cover
+            continue
 
 
-def run_deployment(
-    build_dir: Path, no_recreate: bool = False, remove_orphans: bool = False
-) -> None:
-    """Run deployment."""
+def _print_log(compose_app: docker_compose.TopLevelCommand) -> None:
+    """Print docker container logs."""
+    terminal_width, _ = shutil.get_terminal_size()
+    for service in compose_app.project.service_names:
+        try:
+            click.echo("=" * terminal_width)
+            click.echo(f"Trying to get logs for {service}")
+            click.echo(compose_app.project.client.logs(service))
+        except NotFound:
+            continue
 
-    click.echo(f"Running build @ {build_dir}")
+
+def _kill_containers(compose_app: docker_compose.TopLevelCommand) -> None:
+    """Kill active containers before exiting."""
+    for container in compose_app.project.containers(compose_app.project.service_names):
+        click.echo(f"Trying to kill {container.name}")
+        container.kill()
+
+
+def _load_compose_project(build_dir: Path) -> Project:
+    """Load docker compose project."""
     try:
-        project = docker_compose.project_from_options(build_dir, {})
+        return docker_compose.project_from_options(build_dir, {})
     except ConfigurationError as e:  # pragma: no cover
         if "Invalid interpolation format" in e.msg:
             raise click.ClickException(
@@ -90,11 +111,21 @@ def run_deployment(
             )
         raise
 
+
+def run_deployment(
+    build_dir: Path,
+    no_recreate: bool = False,
+    remove_orphans: bool = False,
+    detach: bool = False,
+) -> None:
+    """Run deployment."""
+    click.echo(f"Running build @ {build_dir}")
     try:
+        project = _load_compose_project(build_dir=build_dir)
         commands = docker_compose.TopLevelCommand(project=project)
         commands.up(
             {
-                "--detach": False,
+                "--detach": True,
                 "--no-color": False,
                 "--quiet-pull": False,
                 "--no-deps": False,
@@ -115,6 +146,31 @@ def run_deployment(
                 "SERVICE": None,
             }
         )
+        if detach:
+            click.echo("The service is running...")
+            return
+        click.echo("The service is running, press CTRL + C to stop...")
+        while True:
+            time.sleep(1)
+    except NotFound as e:  # pragma: no cover
+        raise click.ClickException(e.explanation)
+    except ProjectError as e:  # pragma: no cover
+        click.echo("Error occured bringing up the project")
+        _print_log(compose_app=commands)
+        _kill_containers(compose_app=commands)
+        raise click.ClickException(e)
+    except KeyboardInterrupt:  # pragma: no cover
+        stop_deployment(build_dir=build_dir)
+
+
+def stop_deployment(build_dir: Path) -> None:
+    """Stop running deployment."""
+    try:
+        project = _load_compose_project(build_dir=build_dir)
+        commands = docker_compose.TopLevelCommand(project=project)
+        click.echo("\nDon't cancel while stopping services...")
+        commands.down({"--volumes": False, "--remove-orphans": True, "--rmi": None})
+        _kill_containers(compose_app=commands)
     except NotFound as e:  # pragma: no cover
         raise click.ClickException(e.explanation)
 
@@ -125,7 +181,6 @@ def build_deployment(  # pylint: disable=too-many-arguments, too-many-locals
     deployment_type: str,
     dev_mode: bool,
     number_of_agents: Optional[int] = None,
-    password: Optional[str] = None,
     packages_dir: Optional[Path] = None,
     open_aea_dir: Optional[Path] = None,
     open_autonomy_dir: Optional[Path] = None,
@@ -139,6 +194,7 @@ def build_deployment(  # pylint: disable=too-many-arguments, too-many-locals
     use_acn: bool = False,
     use_tm_testnet_setup: bool = False,
     image_author: Optional[str] = None,
+    resources: Optional[Resources] = None,
 ) -> None:
     """Build deployment."""
 
@@ -158,7 +214,6 @@ def build_deployment(  # pylint: disable=too-many-arguments, too-many-locals
         service_path=Path.cwd(),
         type_of_deployment=deployment_type,
         keys_file=keys_file,
-        private_keys_password=password,
         number_of_agents=number_of_agents,
         build_dir=build_dir,
         dev_mode=dev_mode,
@@ -175,6 +230,7 @@ def build_deployment(  # pylint: disable=too-many-arguments, too-many-locals
         use_acn=use_acn,
         use_tm_testnet_setup=use_tm_testnet_setup,
         image_author=image_author,
+        resources=resources,
     )
     click.echo(report)
 
@@ -185,7 +241,7 @@ def _resolve_on_chain_token_id(
 ) -> Tuple[Dict[str, str], List[str], str, int]:
     """Resolve service metadata from tokenID"""
 
-    ledger_api, _ = get_ledger_and_crypto_objects(chain_type=chain_type)
+    ledger_api, _ = OnChainHelper.get_ledger_and_crypto_objects(chain_type=chain_type)
     contract_address = ContractConfigs.service_registry.contracts[chain_type]
 
     click.echo(f"Fetching service metadata using chain type {chain_type.value}")
@@ -225,8 +281,9 @@ def build_and_deploy_from_token(  # pylint: disable=too-many-arguments, too-many
     n: Optional[int],
     deployment_type: str,
     aev: bool = False,
-    password: Optional[str] = None,
     no_deploy: bool = False,
+    detach: bool = False,
+    resources: Optional[Resources] = None,
 ) -> None:
     """Build and run deployment from tokenID."""
 
@@ -258,7 +315,7 @@ def build_and_deploy_from_token(  # pylint: disable=too-many-arguments, too-many
             multisig_address=multisig_address,
             consensus_threshold=consensus_threshold,
             apply_environment_variables=aev,
-            password=password,
+            resources=resources,
         )
         if not skip_image:
             click.echo("Building required images.")
@@ -270,4 +327,4 @@ def build_and_deploy_from_token(  # pylint: disable=too-many-arguments, too-many
         return
 
     click.echo("Running deployment")
-    run_deployment(build_dir)
+    run_deployment(build_dir, detach=detach)
