@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2023 Valory AG
+#   Copyright 2021-2024 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -18,10 +18,16 @@
 # ------------------------------------------------------------------------------
 
 """Docker-compose Deployment Generator."""
+import ipaddress
 from pathlib import Path
-from typing import Dict, Optional
+from typing import Dict, List, Optional, cast
 
-from aea.configurations.constants import DEFAULT_LEDGER, PRIVATE_KEY_PATH_SCHEMA
+from aea.configurations.constants import (
+    DEFAULT_LEDGER,
+    LEDGER,
+    PRIVATE_KEY,
+    PRIVATE_KEY_PATH_SCHEMA,
+)
 from docker import from_env
 
 from autonomy.constants import (
@@ -34,14 +40,17 @@ from autonomy.constants import (
     TENDERMINT_IMAGE_NAME,
     TENDERMINT_IMAGE_VERSION,
 )
-from autonomy.deploy.base import BaseDeploymentGenerator
+from autonomy.deploy.base import (
+    BaseDeploymentGenerator,
+    DEFAULT_RESOURCE_VALUES,
+    Resources,
+    tm_write_to_log,
+)
 from autonomy.deploy.constants import (
     DEFAULT_ENCODING,
     DEPLOYMENT_AGENT_KEY_DIRECTORY_SCHEMA,
     DEPLOYMENT_KEY_DIRECTORY,
     INFO,
-    KEY_SCHEMA_PRIVATE_KEY,
-    KEY_SCHEMA_TYPE,
 )
 from autonomy.deploy.generators.docker_compose.templates import (
     ABCI_NODE_TEMPLATE,
@@ -55,30 +64,37 @@ from autonomy.deploy.generators.docker_compose.templates import (
 )
 
 
-# We will add one ACN and hardhat nodes at the top with IP being 192.167.11.2
-# and 192.167.11.3 so we will start from 192.167.11.4 for abci and tendermint nodes
-N_RESERVED_IP_ADDRESSES = 4
+NETWORK_ADDRESS_OFFSET = 1
+BASE_SUBNET = cast(ipaddress.IPv4Network, ipaddress.ip_network("192.167.11.0/24"))
+SUBNET_OVERFLOW = 256
 
 DEFAULT_PACKAGES_PATH = Path.cwd().absolute() / "packages"
 DEFAULT_OPEN_AEA_DIR: Path = Path.home().absolute() / "open-aea"
 DEFAULT_OPEN_AUTONOMY_DIR: Path = Path.home().absolute() / "open-autonomy"
 
 
-def build_tendermint_node_config(
+def build_tendermint_node_config(  # pylint: disable=too-many-arguments
     node_id: int,
+    container_name: str,
+    abci_node: str,
+    network_name: str,
+    network_address: str,
     dev_mode: bool = False,
     log_level: str = INFO,
     tendermint_ports: Optional[Dict[int, int]] = None,
 ) -> str:
     """Build tendermint node config for docker compose."""
-
     config = TENDERMINT_NODE_TEMPLATE.format(
         node_id=node_id,
-        localnet_address_postfix=node_id + N_RESERVED_IP_ADDRESSES,
+        container_name=container_name,
+        abci_node=abci_node,
+        network_address=network_address,
         localnet_port_range=node_id,
         log_level=log_level,
         tendermint_image_name=TENDERMINT_IMAGE_NAME,
         tendermint_image_version=TENDERMINT_IMAGE_VERSION,
+        network_name=network_name,
+        write_to_log=str(tm_write_to_log()).lower(),
     )
 
     if dev_mode:
@@ -97,25 +113,33 @@ def build_tendermint_node_config(
     return config
 
 
-def build_agent_config(  # pylint: disable=too-many-arguments
+def build_agent_config(  # pylint: disable=too-many-arguments,too-many-locals
     node_id: int,
-    number_of_agents: int,
+    container_name: str,
     agent_vars: Dict,
     runtime_image: str,
+    network_name: str,
+    network_address: str,
     dev_mode: bool = False,
     package_dir: Path = DEFAULT_PACKAGES_PATH,
     open_aea_dir: Path = DEFAULT_OPEN_AEA_DIR,
     open_autonomy_dir: Path = DEFAULT_OPEN_AUTONOMY_DIR,
     agent_ports: Optional[Dict[int, int]] = None,
+    resources: Optional[Resources] = None,
 ) -> str:
     """Build agent config."""
-
+    resources = resources if resources is not None else DEFAULT_RESOURCE_VALUES
     agent_vars_string = "\n".join([f"      - {k}={v}" for k, v in agent_vars.items()])
     config = ABCI_NODE_TEMPLATE.format(
         node_id=node_id,
+        container_name=container_name,
         agent_vars=agent_vars_string,
-        localnet_address_postfix=node_id + number_of_agents + N_RESERVED_IP_ADDRESSES,
+        network_address=network_address,
         runtime_image=runtime_image,
+        network_name=network_name,
+        agent_memory_request=resources["agent"]["requested"]["memory"],
+        agent_cpu_limit=resources["agent"]["limit"]["cpu"],
+        agent_memory_limit=resources["agent"]["limit"]["memory"],
     )
 
     if dev_mode:
@@ -139,6 +163,58 @@ def build_agent_config(  # pylint: disable=too-many-arguments
     return config
 
 
+class Network:
+    """Class to represent network of the service."""
+
+    def __init__(
+        self,
+        name: str,
+        base: ipaddress.IPv4Network = BASE_SUBNET,
+    ) -> None:
+        """Initialize."""
+        self.name = name
+        self.base = base
+        self.subnet = self.build()
+
+        self._address_offeset = NETWORK_ADDRESS_OFFSET
+
+    @staticmethod
+    def next_subnet(subnet: ipaddress.IPv4Network) -> ipaddress.IPv4Network:
+        """Calculat next available subnet."""
+        new_address = subnet.network_address + SUBNET_OVERFLOW
+        return cast(
+            ipaddress.IPv4Network,
+            ipaddress.ip_network(f"{new_address}/{subnet.prefixlen}"),
+        )
+
+    def build(
+        self,
+    ) -> ipaddress.IPv4Network:
+        """Initialize network params."""
+        docker = from_env()
+        used_subnets = set()
+        for network in docker.networks.list():
+            # Network already exists
+            if f"abci_build_{self.name}" == network.attrs["Name"]:
+                config, *_ = network.attrs["IPAM"]["Config"]
+                return cast(
+                    ipaddress.IPv4Network, ipaddress.ip_network(config["Subnet"])
+                )
+            for config in network.attrs["IPAM"]["Config"]:
+                used_subnets.add(config["Subnet"])
+
+        subnet = self.base
+        while str(subnet) in used_subnets:
+            subnet = self.next_subnet(subnet=subnet)
+        return subnet
+
+    @property
+    def next_address(self) -> str:
+        """Returns the next IP address string."""
+        self._address_offeset += 1
+        return str(self.subnet.network_address + self._address_offeset)
+
+
 class DockerComposeGenerator(BaseDeploymentGenerator):
     """Class to automate the generation of Deployments."""
 
@@ -151,13 +227,11 @@ class DockerComposeGenerator(BaseDeploymentGenerator):
         if not self.use_tm_testnet_setup:
             return self
 
-        hosts = (
-            " \\\n".join(
-                [
-                    f"--hostname=node{k}"
-                    for k in range(self.service_builder.service.number_of_agents)
-                ]
-            ),
+        hosts = " ".join(
+            [
+                "--hostname=" + self.service_builder.get_tm_container_name(index=k)
+                for k in range(self.service_builder.service.number_of_agents)
+            ]
         )
         self.tendermint_job_config = TENDERMINT_CONFIG_TEMPLATE.format(
             validators=self.service_builder.service.number_of_agents, hosts=hosts
@@ -182,6 +256,8 @@ class DockerComposeGenerator(BaseDeploymentGenerator):
     ) -> "DockerComposeGenerator":
         """Generate the new configuration."""
 
+        network_name = f"service_{self.service_builder.service.name}_localnet"
+        network = Network(name=network_name)
         image_version = image_version or self.service_builder.service.agent.hash
         if self.dev_mode:
             image_version = "dev"
@@ -192,12 +268,13 @@ class DockerComposeGenerator(BaseDeploymentGenerator):
             version=image_version,
         )
         agent_vars = self.service_builder.generate_agents()
-
         agents = "".join(
             [
                 build_agent_config(
                     node_id=i,
-                    number_of_agents=self.service_builder.service.number_of_agents,
+                    container_name=self.service_builder.get_abci_container_name(
+                        index=i
+                    ),
                     runtime_image=runtime_image,
                     agent_vars=agent_vars[i],
                     dev_mode=self.dev_mode,
@@ -209,6 +286,9 @@ class DockerComposeGenerator(BaseDeploymentGenerator):
                         .get("ports", {})
                         .get(i)
                     ),
+                    network_name=network_name,
+                    network_address=network.next_address,
+                    resources=self.resources,
                 )
                 for i in range(self.service_builder.service.number_of_agents)
             ]
@@ -217,6 +297,8 @@ class DockerComposeGenerator(BaseDeploymentGenerator):
             [
                 build_tendermint_node_config(
                     node_id=i,
+                    container_name=self.service_builder.get_tm_container_name(index=i),
+                    abci_node=self.service_builder.get_abci_container_name(index=i),
                     dev_mode=self.dev_mode,
                     log_level=self.service_builder.log_level,
                     tendermint_ports=(
@@ -226,6 +308,8 @@ class DockerComposeGenerator(BaseDeploymentGenerator):
                         .get("ports", {})
                         .get(i)
                     ),
+                    network_name=network_name,
+                    network_address=network.next_address,
                 )
                 for i in range(self.service_builder.service.number_of_agents)
             ]
@@ -236,6 +320,8 @@ class DockerComposeGenerator(BaseDeploymentGenerator):
             hardhat_node = HARDHAT_NODE_TEMPLATE.format(
                 hardhat_image_name=HARDHAT_IMAGE_NAME,
                 hardhat_image_version=HARDHAT_IMAGE_VERSION,
+                network_name=network_name,
+                network_address=network.next_address,
             )
 
         acn_node = ""
@@ -243,6 +329,8 @@ class DockerComposeGenerator(BaseDeploymentGenerator):
             acn_node = ACN_NODE_TEMPLATE.format(
                 acn_image_name=ACN_IMAGE_NAME,
                 acn_image_version=ACN_IMAGE_VERSION,
+                network_name=network_name,
+                network_address=network.next_address,
             )
 
         self.output = DOCKER_COMPOSE_TEMPLATE.format(
@@ -250,22 +338,47 @@ class DockerComposeGenerator(BaseDeploymentGenerator):
             tendermint_nodes=tendermint_nodes,
             hardhat_node=hardhat_node,
             acn_node=acn_node,
+            network_name=network_name,
+            subnet=str(network.subnet),
         )
 
         return self
 
-    def populate_private_keys(
-        self,
-    ) -> "DockerComposeGenerator":
-        """Populate the private keys to the build directory for docker-compose mapping."""
+    def _populate_keys(self) -> None:
+        """Populate the keys directory"""
         keys_dir = self.build_dir / DEPLOYMENT_KEY_DIRECTORY
         for x in range(self.service_builder.service.number_of_agents):
             path = keys_dir / DEPLOYMENT_AGENT_KEY_DIRECTORY_SCHEMA.format(agent_n=x)
-            ledger = self.service_builder.keys[x].get(KEY_SCHEMA_TYPE, DEFAULT_LEDGER)
-            key = self.service_builder.keys[x][KEY_SCHEMA_PRIVATE_KEY]
+            ledger = cast(List[Dict[str, str]], self.service_builder.keys)[x].get(
+                LEDGER, DEFAULT_LEDGER
+            )
+            key = cast(List[Dict[str, str]], self.service_builder.keys)[x][PRIVATE_KEY]
             keys_file = path / PRIVATE_KEY_PATH_SCHEMA.format(ledger)
             path.mkdir()
             with keys_file.open(mode="w", encoding=DEFAULT_ENCODING) as f:
                 f.write(key)
 
+    def _populate_keys_multiledger(self) -> None:
+        """Populate the keys directory with multiple set of keys"""
+        keys_dir = self.build_dir / DEPLOYMENT_KEY_DIRECTORY
+        for x in range(self.service_builder.service.number_of_agents):
+            path = keys_dir / DEPLOYMENT_AGENT_KEY_DIRECTORY_SCHEMA.format(agent_n=x)
+            path.mkdir(exist_ok=True)
+            for keypair in cast(List[List[Dict[str, str]]], self.service_builder.keys)[
+                x
+            ]:
+                ledger = keypair.get(LEDGER, DEFAULT_LEDGER)
+                key = keypair[PRIVATE_KEY]
+                keys_file = path / PRIVATE_KEY_PATH_SCHEMA.format(ledger)
+                with keys_file.open(mode="w", encoding=DEFAULT_ENCODING) as f:
+                    f.write(key)
+
+    def populate_private_keys(
+        self,
+    ) -> "DockerComposeGenerator":
+        """Populate the private keys to the build directory for docker-compose mapping."""
+        if self.service_builder.multiledger:
+            self._populate_keys_multiledger()
+        else:
+            self._populate_keys()
         return self
