@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2023 Valory AG
+#   Copyright 2021-2024 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -20,23 +20,18 @@
 """Deployment Templates."""
 
 
-TENDERMINT_CONFIG_TEMPLATE: str = """/usr/bin/tendermint testnet \
-        --config /etc/tendermint/config-template.toml \
-        --v {validators} \
-        --o . \
-        {hosts}
-"""
+TENDERMINT_CONFIG_TEMPLATE: str = """/usr/bin/tendermint testnet --config /etc/tendermint/config-template.toml --v {validators} --o . {hosts}"""
 
 DOCKER_COMPOSE_TEMPLATE: str = """version: "2.4"
 services:
 {hardhat_node}{acn_node}{tendermint_nodes}{abci_nodes}
 networks:
-  localnet:
+  {network_name}:
     driver: bridge
     ipam:
       driver: default
       config:
-        - subnet: 192.167.11.0/24
+        - subnet: {subnet}
 """
 
 ACN_NODE_TEMPLATE: str = """  acn:
@@ -51,8 +46,8 @@ ACN_NODE_TEMPLATE: str = """  acn:
       - AEA_P2P_URI_MONITORING=0.0.0.0:8081
     entrypoint: ["python3", "-u", "/acn/node/run_acn_node_standalone.py", "/acn/node/libp2p_node", "--config-from-env"]
     networks:
-      localnet:
-        ipv4_address: 192.167.11.3
+      {network_name}:
+        ipv4_address: {network_address}
     ports:
       - "9005:9005"
       - "11000:11000"
@@ -64,54 +59,55 @@ HARDHAT_NODE_TEMPLATE: str = """  hardhat:
     ports:
       - "8545:8545"
     networks:
-      localnet:
-        ipv4_address: 192.167.11.2
+      {network_name}:
+        ipv4_address: {network_address}
 """
 
 TENDERMINT_NODE_TEMPLATE: str = """
-  node{node_id}:
+  {container_name}:
     mem_limit: 1024m
     mem_reservation: 256M
     cpus: 0.5
-    container_name: node{node_id}
-    hostname: node{node_id}
+    container_name: {container_name}
+    hostname: {container_name}
     image: "{tendermint_image_name}:{tendermint_image_version}"
     restart: always
     environment:
       - ID={node_id}
-      - PROXY_APP=tcp://abci{node_id}:26658
+      - PROXY_APP=tcp://{abci_node}:26658
       - TMHOME=/tendermint/node{node_id}
       - CREATE_EMPTY_BLOCKS=true
       - DEV_MODE=0
       - LOG_FILE=/logs/node_{node_id}.txt
       - LOG_LEVEL={log_level}
+      - WRITE_TO_LOG={write_to_log}
     working_dir: /tendermint
     command: ["run", "--no-reload", "--host=0.0.0.0", "--port=8080",]
     depends_on:
-      abci{node_id}:
+      {abci_node}:
         condition: service_healthy
     networks:
-      localnet:
-        ipv4_address: 192.167.11.{localnet_address_postfix}
+      {network_name}:
+        ipv4_address: {network_address}
     volumes:
       - ./nodes:/tendermint:Z
       - ./persistent_data/logs:/logs:Z
 """
 
 ABCI_NODE_TEMPLATE: str = """
-  abci{node_id}:
-    mem_limit: 1024m
-    mem_reservation: 256M
-    cpus: 1
-    container_name: abci{node_id}
+  {container_name}:
+    mem_reservation: {agent_memory_request}M
+    mem_limit: {agent_memory_limit}M
+    cpus: {agent_cpu_limit}
+    container_name: {container_name}
     image: {runtime_image}
     environment:
       - PYTHONHASHSEED=0
       - LOG_FILE=/logs/aea_{node_id}.txt
 {agent_vars}
     networks:
-      localnet:
-        ipv4_address: 192.167.11.{localnet_address_postfix}
+      {network_name}:
+        ipv4_address: {network_address}
     extra_hosts:
       - "host.docker.internal:host-gateway"
     volumes:
