@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2023 Valory AG
+#   Copyright 2021-2024 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -19,11 +19,10 @@
 
 """Script to create environment for benchmarking n agents."""
 
-from pathlib import Path
 from typing import Any, Dict, List, Optional, cast
 
 import yaml
-from aea.configurations.constants import DEFAULT_LEDGER
+from aea.configurations.constants import DEFAULT_LEDGER, LEDGER, PRIVATE_KEY
 
 from autonomy.constants import (
     HARDHAT_IMAGE_NAME,
@@ -32,13 +31,13 @@ from autonomy.constants import (
     TENDERMINT_IMAGE_NAME,
     TENDERMINT_IMAGE_VERSION,
 )
-from autonomy.deploy.base import BaseDeploymentGenerator, ServiceBuilder
-from autonomy.deploy.constants import (
-    DEFAULT_ENCODING,
-    KEY_SCHEMA_PRIVATE_KEY,
-    KEY_SCHEMA_TYPE,
-    KUBERNETES_AGENT_KEY_NAME,
+from autonomy.deploy.base import (
+    BaseDeploymentGenerator,
+    DEFAULT_RESOURCE_VALUES,
+    Resources,
+    tm_write_to_log,
 )
+from autonomy.deploy.constants import DEFAULT_ENCODING, KUBERNETES_AGENT_KEY_NAME
 from autonomy.deploy.generators.kubernetes.templates import (
     AGENT_NODE_TEMPLATE,
     AGENT_SECRET_TEMPLATE,
@@ -46,6 +45,8 @@ from autonomy.deploy.generators.kubernetes.templates import (
     HARDHAT_TEMPLATE,
     PORTS_CONFIG_DEPLOYMENT,
     PORT_CONFIG_DEPLOYMENT,
+    SECRET_KEY_TEMPLATE,
+    SECRET_STRING_DATA_TEMPLATE,
 )
 
 
@@ -55,37 +56,16 @@ class KubernetesGenerator(BaseDeploymentGenerator):
     output_name: str = "build.yaml"
     deployment_type: str = "kubernetes"
 
-    def __init__(  # pylint: disable=too-many-arguments
-        self,
-        service_builder: ServiceBuilder,
-        build_dir: Path,
-        dev_mode: bool = False,
-        packages_dir: Optional[Path] = None,
-        open_aea_dir: Optional[Path] = None,
-        open_autonomy_dir: Optional[Path] = None,
-        use_tm_testnet_setup: bool = False,
-        image_author: Optional[str] = None,
-    ) -> None:
-        """Initialise the deployment generator."""
-        super().__init__(
-            service_builder=service_builder,
-            build_dir=build_dir,
-            use_tm_testnet_setup=use_tm_testnet_setup,
-            dev_mode=dev_mode,
-            packages_dir=packages_dir,
-            open_aea_dir=open_aea_dir,
-            open_autonomy_dir=open_autonomy_dir,
-            image_author=image_author,
-        )
-        self.resources: List[str] = []
+    build: List[str]
 
-    def build_agent_deployment(
+    def build_agent_deployment(  # pylint: disable=too-many-locals,too-many-arguments
         self,
         runtime_image: str,
         agent_ix: int,
         number_of_agents: int,
         agent_vars: Dict[str, Any],
         agent_ports: Optional[Dict[int, int]] = None,
+        resources: Optional[Resources] = None,
     ) -> str:
         """Build agent deployment."""
 
@@ -103,22 +83,40 @@ class KubernetesGenerator(BaseDeploymentGenerator):
                 [PORTS_CONFIG_DEPLOYMENT, *port_mappings]
             )
 
+        if self.service_builder.multiledger:
+            keys = ""
+            for keypair in cast(
+                List[Dict[str, str]], self.service_builder.keys[agent_ix]
+            ):
+                keys += SECRET_KEY_TEMPLATE.format(
+                    ledger=keypair.get(LEDGER, DEFAULT_LEDGER)
+                )
+        else:
+            keys = SECRET_KEY_TEMPLATE.format(
+                ledger=cast(List[Dict[str, str]], self.service_builder.keys)[
+                    agent_ix
+                ].get(LEDGER, DEFAULT_LEDGER)
+            )
+
+        resources = resources if resources is not None else DEFAULT_RESOURCE_VALUES
         agent_deployment = AGENT_NODE_TEMPLATE.format(
             runtime_image=runtime_image,
             validator_ix=agent_ix,
-            aea_key=self.service_builder.keys[agent_ix][KEY_SCHEMA_PRIVATE_KEY],
             number_of_validators=number_of_agents,
             host_names=host_names,
             tendermint_image_name=TENDERMINT_IMAGE_NAME,
             tendermint_image_version=TENDERMINT_IMAGE_VERSION,
             log_level=self.service_builder.log_level,
             agent_ports_deployment=agent_ports_deployment,
-            ledger=self.service_builder.keys[agent_ix].get(
-                KEY_SCHEMA_TYPE, DEFAULT_LEDGER
-            ),
+            keys=keys,
+            write_to_log=str(tm_write_to_log()).lower(),
+            agent_cpu_request=resources["agent"]["requested"]["cpu"],
+            agent_memory_request=resources["agent"]["requested"]["memory"],
+            agent_cpu_limit=resources["agent"]["limit"]["cpu"],
+            agent_memory_limit=resources["agent"]["limit"]["memory"],
         )
         agent_deployment_yaml = yaml.load_all(agent_deployment, Loader=yaml.FullLoader)  # type: ignore
-        resources = []
+        build = []
         for resource in agent_deployment_yaml:
             if resource.get("kind") == "Deployment":
                 for container in resource["spec"]["template"]["spec"]["containers"]:
@@ -126,9 +124,9 @@ class KubernetesGenerator(BaseDeploymentGenerator):
                         container["env"] += [
                             {"name": k, "value": f"{v}"} for k, v in agent_vars.items()
                         ]
-            resources.append(resource)
+            build.append(resource)
 
-        res = "\n---\n".join([yaml.safe_dump(i) for i in resources])
+        res = "\n---\n".join([yaml.safe_dump(i) for i in build])
         return res
 
     def generate_config_tendermint(self) -> "KubernetesGenerator":
@@ -161,14 +159,13 @@ class KubernetesGenerator(BaseDeploymentGenerator):
         use_acn: bool = False,
     ) -> "KubernetesGenerator":
         """Generate the deployment."""
-
+        self.build = []
         image_version = image_version or self.service_builder.service.agent.hash
-
         if self.dev_mode:
             image_version = "dev"
 
         if use_hardhat:
-            self.resources.append(
+            self.build.append(
                 HARDHAT_TEMPLATE % (HARDHAT_IMAGE_NAME, HARDHAT_IMAGE_VERSION)
             )
 
@@ -195,12 +192,13 @@ class KubernetesGenerator(BaseDeploymentGenerator):
                         .get("ports", {})
                         .get(i)
                     ),
+                    resources=self.resources,
                 )
                 for i in range(self.service_builder.service.number_of_agents)
             ]
         )
-        self.resources.append(agents)
-        self.output = "\n---\n".join(self.resources)
+        self.build.append(agents)
+        self.output = "\n---\n".join(self.build)
         return self
 
     def write_config(
@@ -218,17 +216,49 @@ class KubernetesGenerator(BaseDeploymentGenerator):
 
         return self
 
-    def populate_private_keys(self) -> "BaseDeploymentGenerator":
-        """Populates private keys into a config map for the kubernetes deployment."""
+    def _populate_keys(self) -> None:
+        """Populate the keys directory"""
         path = self.build_dir / "agent_keys"
         for x in range(self.service_builder.service.number_of_agents):
-            ledger = self.service_builder.keys[x].get(KEY_SCHEMA_TYPE, DEFAULT_LEDGER)
-            key = self.service_builder.keys[x][KEY_SCHEMA_PRIVATE_KEY]
+            ledger = cast(List[Dict[str, str]], self.service_builder.keys)[x].get(
+                LEDGER, DEFAULT_LEDGER
+            )
+            key = cast(List[Dict[str, str]], self.service_builder.keys)[x][PRIVATE_KEY]
+            string_data = SECRET_STRING_DATA_TEMPLATE.format(
+                ledger=ledger, private_key=key
+            )
             secret = AGENT_SECRET_TEMPLATE.format(
-                private_key=key, validator_ix=x, ledger=ledger
+                validator_ix=x, string_data=string_data[:-1]
             )
             with open(
                 path / KUBERNETES_AGENT_KEY_NAME.format(agent_n=x), "w", encoding="utf8"
             ) as f:
                 f.write(secret)
+
+    def _populate_keys_multiledger(self) -> None:
+        """Populate the keys directory with multiple set of keys"""
+        path = self.build_dir / "agent_keys"
+        for x in range(self.service_builder.service.number_of_agents):
+            string_data = ""
+            for keypair in cast(List[List[Dict[str, str]]], self.service_builder.keys)[
+                x
+            ]:
+                ledger = keypair.get(LEDGER, DEFAULT_LEDGER)
+                string_data += SECRET_STRING_DATA_TEMPLATE.format(
+                    ledger=ledger, private_key=keypair[PRIVATE_KEY]
+                )
+            secret = AGENT_SECRET_TEMPLATE.format(
+                validator_ix=x, string_data=string_data[:-1]
+            )
+            with open(
+                path / KUBERNETES_AGENT_KEY_NAME.format(agent_n=x), "w", encoding="utf8"
+            ) as f:
+                f.write(secret)
+
+    def populate_private_keys(self) -> "BaseDeploymentGenerator":
+        """Populates private keys into a config map for the kubernetes deployment."""
+        if self.service_builder.multiledger:
+            self._populate_keys_multiledger()
+        else:
+            self._populate_keys()
         return self
