@@ -18,9 +18,3 @@
 # ------------------------------------------------------------------------------
 
 """Abci connection."""  # pragma: nocover
-from hypothesis import settings
-
-
-CI = "CI"  # pragma: nocover
-
-settings.register_profile(CI, deadline=5000)  # pragma: nocover
