@@ -24,6 +24,7 @@ import os
 import platform
 import signal
 import subprocess  # nosec
+import sys
 from asyncio import AbstractEventLoop, AbstractServer, CancelledError, Task
 from io import BytesIO
 from logging import Logger
@@ -1037,7 +1038,7 @@ class TcpServerChannel:  # pylint: disable=too-many-instance-attributes
 
 class StoppableThread(
     Thread,
-):  # pragma: no cover (covered via deployments/Dockerfiles/tendermint/tendermint.py)
+):
     """Thread class with a stop() method."""
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
@@ -1054,7 +1055,7 @@ class StoppableThread(
         return self._stop_event.is_set()
 
 
-class TendermintParams:  # pylint: disable=too-few-public-methods  # pragma: no cover (covered via deployments/Dockerfiles/tendermint/tendermint.py)
+class TendermintParams:  # pylint: disable=too-few-public-methods
     """Tendermint node parameters."""
 
     def __init__(  # pylint: disable=too-many-arguments
@@ -1115,47 +1116,49 @@ class TendermintParams:  # pylint: disable=too-few-public-methods  # pragma: no
         ]
         if debug:
             cmd.append("--log_level=debug")
-
         if self.home is not None:  # pragma: nocover
             cmd += ["--home", self.home]
         return cmd
 
     @staticmethod
-    def get_node_command_kwargs(monitoring: bool = False) -> Dict:
+    def get_node_command_kwargs() -> Dict:
         """Get the node command kwargs"""
         kwargs = {
             "bufsize": 1,
             "universal_newlines": True,
+            "stdout": subprocess.PIPE,
+            "stderr": subprocess.STDOUT,
         }
-
-        # Only redirect stdout and stderr if we're going to read
-        if monitoring:
-            kwargs["stdout"] = subprocess.PIPE
-            kwargs["stderr"] = subprocess.STDOUT
-
         if platform.system() == "Windows":  # pragma: nocover
             kwargs["creationflags"] = subprocess.CREATE_NEW_PROCESS_GROUP  # type: ignore
         else:
             kwargs["preexec_fn"] = os.setsid  # type: ignore
-
         return kwargs
 
 
 class TendermintNode:
     """A class to manage a Tendermint node."""
 
-    def __init__(self, params: TendermintParams, logger: Optional[Logger] = None):
+    def __init__(
+        self,
+        params: TendermintParams,
+        logger: Optional[Logger] = None,
+        write_to_log: bool = False,
+    ):
         """
         Initialize a Tendermint node.
 
         :param params: the parameters.
         :param logger: the logger.
+        :param write_to_log: Write to log file.
         """
         self.params = params
         self._process: Optional[subprocess.Popen] = None
         self._monitoring: Optional[StoppableThread] = None
+        self._stopping = False
         self.logger = logger or logging.getLogger()
         self.log_file = os.environ.get("LOG_FILE", DEFAULT_TENDERMINT_LOG_FILE)
+        self.write_to_log = write_to_log
 
     def _build_init_command(self) -> List[str]:
         """Build the 'init' command."""
@@ -1172,42 +1175,74 @@ class TendermintNode:
         cmd = self._build_init_command()
         subprocess.call(cmd)  # nosec
 
-    def start(self, start_monitoring: bool = False, debug: bool = False) -> None:
-        """Start a Tendermint node process."""
-        self._start_tm_process(start_monitoring, debug)
-        if start_monitoring:
-            self._start_monitoring_thread()
+    def _monitor_tendermint_process(
+        self,
+    ) -> None:
+        """Check server status."""
+        if self._monitoring is None:
+            raise ValueError("Monitoring is not running")
+        self.log("Monitoring thread started\n")
+        while not self._monitoring.stopped():
+            try:
+                if self._process is not None and self._process.stdout is not None:
+                    line = self._process.stdout.readline()
+                    self.log(line)
+                    for trigger in [
+                        # this occurs when we lose connection from the tm side
+                        "RPC HTTP server stopped",
+                        # whenever the node is stopped because of a closed connection
+                        # from on any of the tendermint modules (abci, p2p, rpc, etc)
+                        # we restart the node
+                        "Stopping abci.socketClient for error: read message: EOF",
+                    ]:
+                        if self._monitoring.stopped():
+                            break
+                        if line.find(trigger) >= 0:
+                            self._stop_tm_process()
+                            # we can only reach this step if monitoring was activated
+                            # so we make sure that after reset the monitoring continues
+                            self._start_tm_process()
+                            self.log(
+                                f"Restarted the HTTP RPC server, as a connection was dropped with message:\n\t\t {line}\n"
+                            )
+            except Exception as e:  # pylint: disable=broad-except
+                self.log(f"Error!: {str(e)}")
+        self.log("Monitoring thread terminated\n")
 
-    def _start_tm_process(self, monitoring: bool = False, debug: bool = False) -> None:
+    def _start_tm_process(self, debug: bool = False) -> None:
         """Start a Tendermint node process."""
-
-        if self._process is not None:  # pragma: nocover
+        if self._process is not None or self._stopping:  # pragma: nocover
             return
-
         cmd = self.params.build_node_command(debug)
-        kwargs = self.params.get_node_command_kwargs(monitoring)
-
-        logging.info(f"Starting Tendermint: {cmd}")
+        kwargs = self.params.get_node_command_kwargs()
+        self.log(f"Starting Tendermint: {cmd}\n")
         self._process = (
             subprocess.Popen(  # nosec # pylint: disable=consider-using-with,W1509
                 cmd, **kwargs
             )
         )
-
-        self.write_line("Tendermint process started\n")
+        self.log("Tendermint process started\n")
 
     def _start_monitoring_thread(self) -> None:
         """Start a monitoring thread."""
-        self._monitoring = StoppableThread(target=self.check_server_status)
+        self._monitoring = StoppableThread(target=self._monitor_tendermint_process)
         self._monitoring.start()
 
+    def start(self, debug: bool = False) -> None:
+        """Start a Tendermint node process."""
+        self._start_tm_process(debug)
+        self._start_monitoring_thread()
+
     def _stop_tm_process(self) -> None:
         """Stop a Tendermint node process."""
-        if self._process is None:
+        if self._process is None or self._stopping:
             return
 
+        self._stopping = True
         if platform.system() == "Windows":
             os.kill(self._process.pid, signal.CTRL_C_EVENT)  # type: ignore  # pylint: disable=no-member
+            if self._process is None:
+                return
             try:
                 self._process.wait(timeout=5)
             except subprocess.TimeoutExpired:  # nosec
@@ -1215,13 +1250,16 @@ class TendermintNode:
         else:
             self._process.send_signal(signal.SIGTERM)
             self._process.wait(timeout=5)
+            if self._process is None:
+                return
             poll = self._process.poll()
             if poll is None:  # pragma: nocover
                 self._process.terminate()
                 self._process.wait(3)
 
+        self._stopping = False
         self._process = None
-        self.write_line("Tendermint process stopped\n")
+        self.log("Tendermint process stopped\n")
 
     def _stop_monitoring_thread(self) -> None:
         """Stop a monitoring process."""
@@ -1231,8 +1269,25 @@ class TendermintNode:
 
     def stop(self) -> None:
         """Stop a Tendermint node process."""
-        self._stop_monitoring_thread()
         self._stop_tm_process()
+        self._stop_monitoring_thread()
+
+    @staticmethod
+    def _write_to_console(line: str) -> None:
+        """Write line to console."""
+        sys.stdout.write(str(line))
+        sys.stdout.flush()
+
+    def _write_to_file(self, line: str) -> None:
+        """Write line to console."""
+        with open(self.log_file, "a", encoding=ENCODING) as file:
+            file.write(line)
+
+    def log(self, line: str) -> None:
+        """Open and write a line to the log file."""
+        self._write_to_console(line=line)
+        if self.write_to_log:
+            self._write_to_file(line=line)
 
     def prune_blocks(self) -> int:
         """Prune blocks from the Tendermint state"""
@@ -1240,46 +1295,6 @@ class TendermintNode:
             ["tendermint", "--home", str(self.params.home), "unsafe-reset-all"]
         )
 
-    def write_line(self, line: str) -> None:
-        """Open and write a line to the log file."""
-        with open(self.log_file, "a", encoding=ENCODING) as file:
-            file.write(line)
-
-    def check_server_status(
-        self,
-    ) -> None:
-        """Check server status."""
-        if self._monitoring is None:
-            raise ValueError("Monitoring is not running")
-        self.write_line("Monitoring thread started\n")
-        while True:
-            try:
-                if self._monitoring.stopped():
-                    break  # break from the loop immediately.
-                if self._process is not None and self._process.stdout is not None:
-                    line = self._process.stdout.readline()
-                    self.write_line(line)
-                    for trigger in [
-                        # this occurs when we lose connection from the tm side
-                        "RPC HTTP server stopped",
-                        # whenever the node is stopped because of a closed connection
-                        # from on any of the tendermint modules (abci, p2p, rpc, etc)
-                        # we restart the node
-                        "Stopping abci.socketClient for error: read message: EOF",
-                    ]:
-                        if line.find(trigger) >= 0:
-                            self._stop_tm_process()
-                            # we can only reach this step if monitoring was activated
-                            # so we make sure that after reset the monitoring continues
-                            monitoring = True
-                            self._start_tm_process(monitoring)
-                            self.write_line(
-                                f"Restarted the HTTP RPC server, as a connection was dropped with message:\n\t\t {line}\n"
-                            )
-            except Exception as e:  # pylint: disable=broad-except
-                self.write_line(f"Error!: {str(e)}")
-        self.write_line("Monitoring thread terminated\n")
-
     def reset_genesis_file(
         self, genesis_time: str, initial_height: str, period_count: str
     ) -> None:
