@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2023 valory
+#   Copyright 2024 valory
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -22,13 +22,16 @@
 # pylint: disable=too-many-statements,too-many-locals,no-member,too-few-public-methods,redefined-builtin
 from typing import Any, Dict, cast
 
-from aea.mail.base_pb2 import DialogueMessage
-from aea.mail.base_pb2 import Message as ProtobufMessage
-from aea.protocols.base import Message, Serializer
+from aea.mail.base_pb2 import DialogueMessage  # type: ignore
+from aea.mail.base_pb2 import Message as ProtobufMessage  # type: ignore
+from aea.protocols.base import Message  # type: ignore
+from aea.protocols.base import Serializer  # type: ignore
 
-from packages.valory.protocols.tendermint import tendermint_pb2
-from packages.valory.protocols.tendermint.custom_types import ErrorCode
-from packages.valory.protocols.tendermint.message import TendermintMessage
+from packages.valory.protocols.tendermint import tendermint_pb2  # type: ignore
+from packages.valory.protocols.tendermint.custom_types import ErrorCode  # type: ignore
+from packages.valory.protocols.tendermint.message import (  # type: ignore
+    TendermintMessage,
+)
 
 
 class TendermintSerializer(Serializer):
@@ -45,7 +48,7 @@ class TendermintSerializer(Serializer):
         msg = cast(TendermintMessage, msg)
         message_pb = ProtobufMessage()
         dialogue_message_pb = DialogueMessage()
-        tendermint_msg = tendermint_pb2.TendermintMessage()
+        tendermint_msg = tendermint_pb2.TendermintMessage()  # type: ignore
 
         dialogue_message_pb.message_id = msg.message_id
         dialogue_reference = msg.dialogue_reference
@@ -105,7 +108,7 @@ class TendermintSerializer(Serializer):
         :return: the 'Tendermint' message.
         """
         message_pb = ProtobufMessage()
-        tendermint_pb = tendermint_pb2.TendermintMessage()
+        tendermint_pb = tendermint_pb2.TendermintMessage()  # type: ignore
         message_pb.ParseFromString(obj)
         message_id = message_pb.dialogue_message.message_id
         dialogue_reference = (
