@@ -270,26 +270,6 @@ def test_async_behaviour_wait_for_message_raises_timeout_exception() -> None:
         try_send(gen)
 
 
-def test_async_behaviour_wait_for_message_raises_timeout_exception_when_no_message() -> (
-    None
-):
-    """Test 'wait_for_message' when it raises TimeoutException."""
-
-    with pytest.raises(TimeoutException):
-        behaviour = AsyncBehaviourTest()
-        behaviour.act()
-        gen = behaviour.wait_for_message(lambda _: False, timeout=0.01)
-        # simulate the generator is waiting for a message
-        behaviour._AsyncBehaviour__generator_act = gen  # type: ignore
-        behaviour._AsyncBehaviour__state = AsyncBehaviour.AsyncState.WAITING_MESSAGE  # type: ignore
-        # the message never arrives, a timeout exception should be raised
-        behaviour.act()
-        # sleep so to run out the timeout
-        time.sleep(0.02)
-        # trigger function and make the exception to raise
-        behaviour.act()
-
-
 def test_async_behaviour_wait_for_condition() -> None:
     """Test 'wait_for_condition' method."""
 
@@ -1293,7 +1273,13 @@ class TestBaseBehaviour:
                         ledger_id="ethereum_flashbots",
                         signed_transactions=[{"test_tx": "test_tx"}],
                     ),
-                    kwargs=LedgerApiMessage.Kwargs({}),
+                    kwargs=LedgerApiMessage.Kwargs(
+                        {
+                            "chain_id": None,
+                            "raise_on_failed_simulation": False,
+                            "use_all_builders": True,
+                        }
+                    ),
                 ),
             ),
             (
@@ -1306,7 +1292,14 @@ class TestBaseBehaviour:
                         ledger_id="ethereum_flashbots",
                         signed_transactions=[{"test_tx": "test_tx"}],
                     ),
-                    kwargs=LedgerApiMessage.Kwargs({"target_block_numbers": [1, 2, 3]}),
+                    kwargs=LedgerApiMessage.Kwargs(
+                        {
+                            "chain_id": None,
+                            "raise_on_failed_simulation": False,
+                            "use_all_builders": True,
+                            "target_block_numbers": [1, 2, 3],
+                        }
+                    ),
                 ),
             ),
             (
