@@ -18,8 +18,9 @@
 # ------------------------------------------------------------------------------
 
 """Tests for valory/register_reset_recovery skill's behaviours."""
+
 from pathlib import Path
-from typing import Any, Dict, Generator, Optional, Type
+from typing import Any, Dict, Optional, Type
 from unittest import mock
 
 from packages.valory.skills.abstract_round_abci.base import (
@@ -84,14 +85,7 @@ class TestShareRoundCountBehaviour(BaseTerminationTest):
     def test_run(self) -> None:
         """Run the behaviour."""
 
-        def mock_sleep() -> Generator:
-            """Mocks BaseBehaviour.sleep()"""
-            return
-            yield
-
         self.fast_forward()
-        with mock.patch.object(
-            self.behaviour.current_behaviour, "sleep", side_effects=mock_sleep()
-        ):
+        with mock.patch.object(self.behaviour.current_behaviour, "sleep"):
             self.behaviour.act_wrapper()
             self.complete()
