@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2022 Valory AG
+#   Copyright 2022-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -62,4 +62,4 @@ def test_RegisterSafeTerminationAbciAppConsensusBehaviour() -> None:
         *ResetPauseABCIConsensusBehaviour.behaviours,
         *TerminationAbciBehaviours.behaviours,
     }
-    assert behaviour.background_behaviour_cls == BackgroundBehaviour
+    assert behaviour.background_behaviours_cls == {BackgroundBehaviour}
