@@ -27,6 +27,7 @@ import json
 import logging
 import time
 from contextlib import ExitStack, contextmanager
+from copy import deepcopy
 from pathlib import Path
 from typing import Any, Callable, Dict, Generator, Iterable, List, Optional, cast
 from unittest import mock
@@ -119,9 +120,12 @@ class BaseRegistrationTestBehaviour(RegistrationAbciBaseCase):
     @pytest.mark.parametrize(
         "setup_data, expected_initialisation",
         (
-            ({}, '{"0": {}}'),
-            ({"test": []}, '{"0": {}}'),
-            ({"test": [], "valid": [1, 2]}, '{"0": {"valid": [1, 2]}}'),
+            ({}, '{"db_data": {"0": {}}, "slashing_config": ""}'),
+            ({"test": []}, '{"db_data": {"0": {}}, "slashing_config": ""}'),
+            (
+                {"test": [], "valid": [1, 2]},
+                '{"db_data": {"0": {"valid": [1, 2]}}, "slashing_config": ""}',
+            ),
         ),
     )
     def test_registration(
@@ -315,9 +319,11 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
 
     def mock_get_tendermint_info(self, *addresses: str) -> None:
         """Mock get Tendermint info"""
-        for _ in addresses:
+        for i in addresses:
             request_kwargs: Dict = dict()
-            info = json.dumps(DUMMY_VALIDATOR_CONFIG)
+            config = deepcopy(DUMMY_VALIDATOR_CONFIG)
+            config["address"] = str(config["address"]) + i
+            info = json.dumps(config)
             response_kwargs = dict(info=info)
             self.mock_tendermint_request(request_kwargs, response_kwargs)
         # give room to the behaviour to finish sleeping
@@ -527,7 +533,19 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
             self.mock_is_correct_contract()
             self.mock_get_agent_instances(*self.agent_instances)
             self.mock_get_tendermint_info(*self.other_agents)
-            assert all(map(self.state.initial_tm_configs.get, self.other_agents))
+
+            initial_tm_configs = self.state.initial_tm_configs
+            validator_to_agent = (
+                self.state.context.state.round_sequence.validator_to_agent
+            )
+
+            assert all(map(initial_tm_configs.get, self.other_agents))
+            assert tuple(validator_to_agent.keys()) == tuple(
+                config["address"] for config in initial_tm_configs.values()
+            )
+            assert tuple(validator_to_agent.values()) == tuple(
+                initial_tm_configs.keys()
+            )
             log_message = self.state.LogMessages.collection_complete
             assert log_message.value in caplog.text
 
