@@ -37,6 +37,7 @@ from typing import (
     cast,
 )
 from unittest import mock
+from unittest.mock import MagicMock
 
 import pytest
 
@@ -262,6 +263,7 @@ class BaseValidateRoundTest(BaseVotingRoundTest):
 
         test_round = self.test_class(
             synchronized_data=self.synchronized_data,
+            context=MagicMock(),
         )
 
         self._complete_run(
@@ -287,6 +289,7 @@ class BaseValidateRoundTest(BaseVotingRoundTest):
 
         test_round = self.test_class(
             synchronized_data=self.synchronized_data,
+            context=MagicMock(),
         )
 
         self._complete_run(
@@ -310,6 +313,7 @@ class BaseValidateRoundTest(BaseVotingRoundTest):
 
         test_round = self.test_class(
             synchronized_data=self.synchronized_data,
+            context=MagicMock(),
         )
 
         self._complete_run(
@@ -353,6 +357,7 @@ class BaseSelectKeeperRoundTest(BaseCollectSameUntilThresholdRoundTest):
             synchronized_data=self.synchronized_data.update(
                 keepers=keepers,
             ),
+            context=MagicMock(),
         )
 
         self._complete_run(
@@ -618,6 +623,7 @@ class TestFinalizationRound(BaseOnlyKeeperSendsRoundTest):
 
         test_round = self._round_class(
             synchronized_data=self.synchronized_data,
+            context=MagicMock(),
         )
 
         self._complete_run(
@@ -667,6 +673,7 @@ class TestFinalizationRound(BaseOnlyKeeperSendsRoundTest):
 
         test_round = self._round_class(
             synchronized_data=self.synchronized_data,
+            context=MagicMock(),
         )
 
         self._complete_run(
@@ -702,6 +709,7 @@ class TestCollectSignatureRound(BaseCollectDifferentUntilThresholdRoundTest):
 
         test_round = CollectSignatureRound(
             synchronized_data=self.synchronized_data,
+            context=MagicMock(),
         )
 
         self._complete_run(
@@ -750,6 +758,12 @@ class TestCheckTransactionHistoryRound(BaseCollectSameUntilThresholdRoundTest):
                 {},
                 TransactionSettlementEvent.NONE,
             ),
+            (
+                "0000000000000000000000000000000000000000000000000000000000000007",
+                "b0e6add595e00477cf347d09797b156719dc5233283ac76e4efce2a674fe72d9",
+                {},
+                TransactionSettlementEvent.NONE,
+            ),
             (
                 "0000000000000000000000000000000000000000000000000000000000000002",
                 "b0e6add595e00477cf347d09797b156719dc5233283ac76e4efce2a674fe72d9",
@@ -771,6 +785,7 @@ class TestCheckTransactionHistoryRound(BaseCollectSameUntilThresholdRoundTest):
 
         test_round = CheckTransactionHistoryRound(
             synchronized_data=self.synchronized_data,
+            context=MagicMock(),
         )
 
         self._complete_run(
@@ -833,6 +848,7 @@ class TestSynchronizeLateMessagesRound(BaseCollectNonEmptyUntilThresholdRound):
         self.synchronized_data.update(missed_messages=missed_messages)
         test_round = SynchronizeLateMessagesRound(
             synchronized_data=self.synchronized_data,
+            context=MagicMock(),
         )
         late_arriving_tx_hashes = {
             p: "".join(("1" * TX_HASH_LENGTH, "2" * TX_HASH_LENGTH))
@@ -865,6 +881,7 @@ class TestSynchronizeLateMessagesRound(BaseCollectNonEmptyUntilThresholdRound):
 
         test_round = SynchronizeLateMessagesRound(
             synchronized_data=self.synchronized_data,
+            context=MagicMock(),
         )
         sender = list(test_round.accepting_payloads_from).pop()
         hash_length = TX_HASH_LENGTH
@@ -987,7 +1004,10 @@ class TestResetRound(BaseCollectSameUntilThresholdRoundTest):
         synchronized_data._db._cross_period_persisted_keys = frozenset(
             {"most_voted_randomness"}
         )
-        test_round = ResetRound(synchronized_data=synchronized_data)
+        test_round = ResetRound(
+            synchronized_data=synchronized_data,
+            context=MagicMock(),
+        )
         next_period_count = 1
         self._complete_run(
             self._test_round(
