@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -24,6 +24,7 @@ import re
 import shutil
 import subprocess  # nosec
 import sys
+from concurrent.futures import ThreadPoolExecutor
 from pathlib import Path
 from typing import Set
 
@@ -127,7 +128,7 @@ def should_skip(module_path: Path) -> bool:
     return False
 
 
-def _generate_apidocs_aea_modules() -> None:
+def _generate_apidocs_aea_modules(executor: ThreadPoolExecutor) -> None:
     """Generate API docs for aea.* modules."""
     for module_path in filter(is_not_dir, Path(AEA_DIR).rglob("*")):
         print(f"Processing {module_path}... ", end="")
@@ -138,10 +139,10 @@ def _generate_apidocs_aea_modules() -> None:
         last = module_path.stem
         doc_file = API_DIR / Path(*parents_without_root) / f"{last}.md"
         dotted_path = ".".join(parents) + "." + last
-        make_pydoc(dotted_path, doc_file)
+        executor.submit(make_pydoc, dotted_path, doc_file)
 
 
-def _generate_apidocs_packages() -> None:
+def _generate_apidocs_packages(executor: ThreadPoolExecutor) -> None:
     """Generate API docs for default packages."""
     for component_type, default_package in DEFAULT_PACKAGES:
         public_id = PublicId.from_str(default_package)
@@ -156,10 +157,10 @@ def _generate_apidocs_packages() -> None:
             suffix = Path(str(module_path.relative_to(package_dir))[:-3] + ".md")
             dotted_path = ".".join(module_path.parts)[:-3]
             doc_file = API_DIR / type_plural / name / suffix
-            make_pydoc(dotted_path, doc_file)
+            executor.submit(make_pydoc, dotted_path, doc_file)
 
 
-def _generate_apidocs_plugins() -> None:
+def _generate_apidocs_plugins(executor: ThreadPoolExecutor) -> None:
     """Generate API docs for cyrpto plugins."""
     for plugin in PLUGIN_DIR.iterdir():
         plugin_name = plugin.name
@@ -174,7 +175,7 @@ def _generate_apidocs_plugins() -> None:
             suffix = Path(str(relative_module_path)[:-3] + ".md")
             dotted_path = ".".join(module_path.parts)[:-3]
             doc_file = API_DIR / "plugins" / plugin_module_name / suffix
-            make_pydoc(dotted_path, doc_file)
+            executor.submit(make_pydoc, dotted_path, doc_file)
 
 
 def make_pydoc(dotted_path: str, dest_file: Path) -> None:
@@ -213,9 +214,10 @@ def generate_api_docs() -> None:
     """Generate the api docs."""
     shutil.rmtree(API_DIR, ignore_errors=True)
     API_DIR.mkdir()
-    _generate_apidocs_packages()
-    _generate_apidocs_aea_modules()
-    _generate_apidocs_plugins()
+    with ThreadPoolExecutor() as executor:
+        _generate_apidocs_packages(executor)
+        _generate_apidocs_aea_modules(executor)
+        _generate_apidocs_plugins(executor)
 
 
 def install(package: str) -> int:
