@@ -35,6 +35,7 @@ from aea_test_autonomy.configurations import (
 )
 
 from autonomy.constants import DEFAULT_BUILD_FOLDER, DEFAULT_DOCKER_IMAGE_AUTHOR
+from autonomy.deploy.base import ServiceBuilder
 from autonomy.deploy.constants import (
     DEBUG,
     DEPLOYMENT_AGENT_KEY_DIRECTORY_SCHEMA,
@@ -59,6 +60,7 @@ class BaseDeployBuildTest(BaseCliTest):
 
     cli_options: Tuple[str, ...] = ("deploy", "build")
     keys_file: Path
+    spec: ServiceBuilder
 
     def setup(self) -> None:
         """Setup test method."""
@@ -71,10 +73,15 @@ class BaseDeployBuildTest(BaseCliTest):
         )
 
         shutil.copytree(
-            self.t / PACKAGES / "valory" / "services" / "hello_world",
-            self.t / "hello_world",
+            self.t / PACKAGES / "valory" / "services" / "register_reset",
+            self.t / "register_reset",
         )
-        os.chdir(self.t / "hello_world")
+        with OS_ENV_PATCH:
+            self.spec = ServiceBuilder.from_dir(
+                self.t / "register_reset",
+                self.keys_file,
+            )
+        os.chdir(self.t / "register_reset")
 
     @staticmethod
     def load_kubernetes_config(
@@ -94,8 +101,8 @@ class BaseDeployBuildTest(BaseCliTest):
             child in build_tree for child in ["persistent_storage", "build.yaml"]
         )
 
-    @staticmethod
     def load_and_check_docker_compose_file(
+        self,
         path: Path,
     ) -> Dict:
         """Load docker compose config."""
@@ -110,8 +117,8 @@ class BaseDeployBuildTest(BaseCliTest):
             [
                 service in docker_compose["services"]
                 for service in [
-                    *map(lambda i: f"abci{i}", range(4)),
-                    *map(lambda i: f"node0{i}", range(4)),
+                    *map(lambda i: self.spec.get_abci_container_name(i), range(4)),
+                    *map(lambda i: self.spec.get_tm_container_name(i), range(4)),
                 ]
             ]
         )
@@ -185,7 +192,7 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
             )
 
         assert result.exit_code == 0, result.output
-        assert (build_dir / "nodes").exists()
+        assert (build_dir / "nodes").exists(), result.stderr
 
     def test_docker_compose_build_log_level(
         self,
@@ -217,10 +224,16 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
         )
 
         assert (
-            f"LOG_LEVEL={DEBUG}" in docker_compose["services"]["abci0"]["environment"]
+            f"LOG_LEVEL={DEBUG}"
+            in docker_compose["services"][self.spec.get_abci_container_name(0)][
+                "environment"
+            ]
         )
         assert (
-            f"LOG_LEVEL={DEBUG}" in docker_compose["services"]["node0"]["environment"]
+            f"LOG_LEVEL={DEBUG}"
+            in docker_compose["services"][self.spec.get_tm_container_name(0)][
+                "environment"
+            ]
         )
 
     def test_docker_compose_build_dev(
@@ -259,12 +272,21 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
 
         assert (
             f"{ROOT_DIR}:/home/ubuntu/packages:rw"
-            in docker_compose["services"]["abci0"]["volumes"]
+            in docker_compose["services"][self.spec.get_abci_container_name(index=0)][
+                "volumes"
+            ]
+        )
+        assert (
+            f"{ROOT_DIR}:/open-aea"
+            in docker_compose["services"][self.spec.get_abci_container_name(index=0)][
+                "volumes"
+            ]
         )
-        assert f"{ROOT_DIR}:/open-aea" in docker_compose["services"]["abci0"]["volumes"]
         assert (
             f"{ROOT_DIR}:/open-autonomy"
-            in docker_compose["services"]["abci0"]["volumes"]
+            in docker_compose["services"][self.spec.get_abci_container_name(index=0)][
+                "volumes"
+            ]
         )
 
     def test_docker_compose_password(
@@ -286,12 +308,14 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
             )
 
         build_dir = self.t / DEFAULT_BUILD_FOLDER
-
-        assert result.exit_code == 0, result.output
+        assert result.exit_code == 0, result.stderr
+        assert (
+            "WARNING: `--password` flag has been deprecated, use `OPEN_AUTONOMY_PRIVATE_KEY_PASSWORD` to export the password value"
+            in result.stdout
+        )
         assert build_dir.exists()
 
         build_dir = self.t / DEFAULT_BUILD_FOLDER
-
         assert result.exit_code == 0, result.output
         assert build_dir.exists()
 
@@ -299,8 +323,6 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
         with open(docker_compose_file, "r", encoding="utf-8") as fp:
             docker_compose = yaml.safe_load(fp)
 
-        agents = int(len(docker_compose["services"]) / 2)
-
         def _file_check(n: int) -> bool:
             return (
                 build_dir
@@ -308,16 +330,19 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
                 / DEPLOYMENT_AGENT_KEY_DIRECTORY_SCHEMA.format(agent_n=n)
             ).exists()
 
+        agents = int(len(docker_compose["services"]) / 2)
         assert all(_file_check(i) for i in range(agents))
         for x in range(agents):
             env = dict(
                 [
                     f.split("=")
-                    for f in docker_compose["services"][f"abci{x}"]["environment"]
+                    for f in docker_compose["services"][
+                        self.spec.get_abci_container_name(x)
+                    ]["environment"]
                 ]
             )
             assert "AEA_PASSWORD" in env.keys()
-            assert env["AEA_PASSWORD"] == ETHEREUM_ENCRYPTION_PASSWORD
+            assert env["AEA_PASSWORD"] == "$OPEN_AUTONOMY_PRIVATE_KEY_PASSWORD"
 
     def test_include_acn_and_hardhat_nodes(
         self,
@@ -424,7 +449,9 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
         )
 
         assert (
-            docker_compose["services"]["abci0"]["image"].split("/")[0]
+            docker_compose["services"][self.spec.get_abci_container_name(0)][
+                "image"
+            ].split("/")[0]
             == get_default_author_from_cli_config()
             or DEFAULT_DOCKER_IMAGE_AUTHOR
         )
@@ -462,7 +489,10 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
         )
 
         assert (
-            docker_compose["services"]["abci0"]["image"].split("/")[0] == image_author
+            docker_compose["services"][self.spec.get_abci_container_name(0)][
+                "image"
+            ].split("/")[0]
+            == image_author
         )
 
 
@@ -572,6 +602,10 @@ class TestKubernetesBuild(BaseDeployBuildTest):
             )
 
         assert result.exit_code == 0, result.output
+        assert (
+            "WARNING: `--password` flag has been deprecated, use `OPEN_AUTONOMY_PRIVATE_KEY_PASSWORD` to export the password value"
+            in result.stdout
+        )
         assert build_dir.exists()
 
         kubernetes_config = self.load_kubernetes_config(
@@ -584,7 +618,7 @@ class TestKubernetesBuild(BaseDeployBuildTest):
             except (KeyError, IndexError):
                 continue
 
-            assert agent_vars["AEA_PASSWORD"] == ETHEREUM_ENCRYPTION_PASSWORD
+            assert agent_vars["AEA_PASSWORD"] == ""
 
         assert all(
             (
@@ -705,6 +739,12 @@ class TestExposePorts(BaseDeployBuildTest):
         with open("./service.yaml", "w+") as fp:
             yaml.dump_all(service_data, fp)
 
+        with OS_ENV_PATCH:
+            self.spec = ServiceBuilder.from_dir(
+                self.t / "register_reset",
+                self.keys_file,
+            )
+
     def test_expose_agent_ports_docker_compose(self) -> None:
         """Test expose agent ports"""
 
@@ -724,13 +764,16 @@ class TestExposePorts(BaseDeployBuildTest):
         self.check_docker_compose_build(
             build_dir=build_dir,
         )
-
         docker_compose = self.load_and_check_docker_compose_file(
             path=build_dir / DockerComposeGenerator.output_name
         )
 
-        assert docker_compose["services"]["abci0"]["ports"] == ["8080:8081"]
-        assert docker_compose["services"]["node0"]["ports"] == ["26656:26666"]
+        assert docker_compose["services"][self.spec.get_abci_container_name(0)][
+            "ports"
+        ] == ["8080:8081"]
+        assert docker_compose["services"][self.spec.get_tm_container_name(0)][
+            "ports"
+        ] == ["26656:26666"]
 
     def test_expose_agent_ports_kubernetes(self) -> None:
         """Test expose agent ports"""
@@ -772,6 +815,11 @@ class TestLoadEnvVars(BaseDeployBuildTest):
         service_data = get_dummy_service_config(file_number=4)
         with open("./service.yaml", "w+") as fp:
             yaml.dump_all(service_data, fp)
+        with OS_ENV_PATCH:
+            self.spec = ServiceBuilder.from_dir(
+                self.t / "register_reset",
+                self.keys_file,
+            )
 
     def _run_test(self) -> None:
         """Run test."""
@@ -798,13 +846,15 @@ class TestLoadEnvVars(BaseDeployBuildTest):
 
         assert (
             f"{self.env_var_path}={self.env_var_value}"
-            in docker_compose["services"]["abci0"]["environment"]
+            in docker_compose["services"][self.spec.get_abci_container_name(0)][
+                "environment"
+            ]
         )
 
     def test_load_dot_env(self) -> None:
         """Test load `.env` file"""
 
-        (self.t / "hello_world" / DEFAULT_ENV_DOTFILE).write_text(
+        (self.t / "register_reset" / DEFAULT_ENV_DOTFILE).write_text(
             f"{self.env_var}={self.env_var_value}"
         )
         self._run_test()
@@ -813,8 +863,116 @@ class TestLoadEnvVars(BaseDeployBuildTest):
         """Test load `.json` file"""
 
         env_var_value = "ENV_VAR_VALUE"
-        env_file = self.t / "hello_world" / "env.json"
+        env_file = self.t / "register_reset" / "env.json"
         env_file.write_text(json.dumps({self.env_var: env_var_value}))
         self.cli_options = ("deploy", "--env-file", str(env_file.resolve()), "build")
 
         self._run_test()
+
+
+class TestResourceSpecification(BaseDeployBuildTest):
+    """Test expose ports from service config."""
+
+    def setup(self) -> None:
+        """Setup test."""
+        super().setup()
+        service_data = get_dummy_service_config(file_number=4)
+        with open("./service.yaml", "w+") as fp:
+            yaml.dump_all(service_data, fp)
+        with OS_ENV_PATCH:
+            self.spec = ServiceBuilder.from_dir(
+                self.t / "register_reset",
+                self.keys_file,
+            )
+
+    def test_expose_agent_ports_docker_compose(self) -> None:
+        """Test expose agent ports"""
+
+        build_dir = self.t / DEFAULT_BUILD_FOLDER
+        with mock.patch("os.chown"), OS_ENV_PATCH:
+            result = self.run_cli(
+                (
+                    str(self.keys_file),
+                    "--o",
+                    str(self.t / DEFAULT_BUILD_FOLDER),
+                    "--agent-cpu-limit",
+                    "2.0",
+                    "--agent-memory-limit",
+                    "4096",
+                    "--agent-memory-request",
+                    "2048",
+                )
+            )
+
+        assert result.exit_code == 0, result.output
+        assert build_dir.exists()
+
+        self.check_docker_compose_build(
+            build_dir=build_dir,
+        )
+        docker_compose = self.load_and_check_docker_compose_file(
+            path=build_dir / DockerComposeGenerator.output_name
+        )
+
+        assert (
+            docker_compose["services"]["dummyservice_abci_0"]["mem_reservation"]
+            == "2048M"
+        )
+        assert docker_compose["services"]["dummyservice_abci_0"]["mem_limit"] == "4096M"
+        assert docker_compose["services"]["dummyservice_abci_0"]["cpus"] == 2.0
+
+    def test_expose_agent_ports_kubernetes(self) -> None:
+        """Test expose agent ports"""
+
+        build_dir = self.t / DEFAULT_BUILD_FOLDER
+        with mock.patch("os.chown"), OS_ENV_PATCH:
+            result = self.run_cli(
+                (
+                    str(self.keys_file),
+                    "--o",
+                    str(self.t / DEFAULT_BUILD_FOLDER),
+                    "--kubernetes",
+                    "--agent-cpu-request",
+                    "1.0",
+                    "--agent-memory-request",
+                    "2048",
+                    "--agent-cpu-limit",
+                    "2.0",
+                    "--agent-memory-limit",
+                    "4096",
+                )
+            )
+
+        assert result.exit_code == 0, result.output
+        assert build_dir.exists()
+
+        self.check_kubernetes_build(build_dir=build_dir)
+        build_config = self.load_kubernetes_config(build_dir)
+
+        assert (
+            build_config[1]["spec"]["template"]["spec"]["containers"][1]["resources"][
+                "requests"
+            ]["cpu"]
+            == "1.0"
+        )
+
+        assert (
+            build_config[1]["spec"]["template"]["spec"]["containers"][1]["resources"][
+                "requests"
+            ]["memory"]
+            == "2048Mi"
+        )
+
+        assert (
+            build_config[1]["spec"]["template"]["spec"]["containers"][1]["resources"][
+                "limits"
+            ]["cpu"]
+            == "2.0"
+        )
+
+        assert (
+            build_config[1]["spec"]["template"]["spec"]["containers"][1]["resources"][
+                "limits"
+            ]["memory"]
+            == "4096Mi"
+        )
